
# Type: quotient




URI: [biolink:Quotient](https://w3id.org/biolink/vocab/Quotient)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Double](types/Double.md) |
| Root (builtin) type | | **float** |

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | ratio |

